==> flowable-engine-6.5.0-sources.jar: org/flowable/engine/impl/cmd/FindBatchPartsByBatchIdCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.engine.impl.cmd;

import java.util.List;

import org.flowable.batch.api.BatchPart;
import org.flowable.common.engine.impl.interceptor.Command;
import org.flowable.common.engine.impl.interceptor.CommandContext;
import org.flowable.engine.impl.util.CommandContextUtil;

public class FindBatchPartsByBatchIdCmd implements Command<List<BatchPart>> {
    
    protected String batchId;
    protected String status;
    
    public FindBatchPartsByBatchIdCmd(String batchId) {
        this.batchId = batchId;
    }
    
    public FindBatchPartsByBatchIdCmd(String batchId, String status) {
        this.batchId = batchId;
        this.status = status;
    }
    
    @Override
    public List<BatchPart> execute(CommandContext commandContext) {
        if (status != null) {
            return CommandContextUtil.getBatchService(commandContext).findBatchPartsByBatchIdAndStatus(batchId, status);
        } else {
            return CommandContextUtil.getBatchService(commandContext).findBatchPartsByBatchId(batchId);
        }
    }
}

==> flowable-engine-6.8.0-sources.jar: org/flowable/engine/impl/cmd/FindBatchPartsByBatchIdCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.engine.impl.cmd;

import java.util.List;

import org.flowable.batch.api.BatchPart;
import org.flowable.common.engine.impl.interceptor.Command;
import org.flowable.common.engine.impl.interceptor.CommandContext;
import org.flowable.engine.impl.cfg.ProcessEngineConfigurationImpl;
import org.flowable.engine.impl.util.CommandContextUtil;

public class FindBatchPartsByBatchIdCmd implements Command<List<BatchPart>> {
    
    protected String batchId;
    protected String status;
    
    public FindBatchPartsByBatchIdCmd(String batchId) {
        this.batchId = batchId;
    }
    
    public FindBatchPartsByBatchIdCmd(String batchId, String status) {
        this.batchId = batchId;
        this.status = status;
    }
    
    @Override
    public List<BatchPart> execute(CommandContext commandContext) {
        ProcessEngineConfigurationImpl processEngineConfiguration = CommandContextUtil.getProcessEngineConfiguration(commandContext);
        if (status != null) {
            return processEngineConfiguration.getBatchServiceConfiguration().getBatchService().findBatchPartsByBatchIdAndStatus(batchId, status);
        } else {
            return processEngineConfiguration.getBatchServiceConfiguration().getBatchService().findBatchPartsByBatchId(batchId);
        }
    }
}
